@@ -3,7 +3,7 @@ cHaySton<-function(alpha,n, method=NA, n.mc=10000){
   outp$stat.name<-"Hayter-Stone W*"
   
   
-  if(alpha>1||alpha<0||class(alpha)!="numeric"){
+  if(alpha>1||alpha<0||!is.numeric(alpha)){
     cat('Error: Check alpha value! \n')
     return(alpha)
   }     
